======================
 Invenio-DB v1.0.0a10
======================

Invenio-DB v1.0.0a10 was released on July 4, 2016.

About
-----

Database management for Invenio.

*This is an experimental developer preview release.*

What's new
----------

- Initial public release.
- Versioning support using SQLAlchemy-Continuum.

Installation
------------

   $ pip install invenio-db==1.0.0a10

Documentation
-------------

   http://pythonhosted.org/invenio-db/

Happy hacking and thanks for flying Invenio-DB.

| Invenio Development Team
|   Email: info@inveniosoftware.org
|   IRC: #invenio on irc.freenode.net
|   Twitter: http://twitter.com/inveniosoftware
|   GitHub: https://github.com/inveniosoftware/invenio-db
|   URL: http://inveniosoftware.org
